@@ -4,9 +4,14 @@ Collection of internal utilities (convenience functions and classes) for data ha
 import glob
 import hashlib
 import os
-from collections import Iterable
 from typing import Tuple
 import numpy as np
+try:
+    # Python <= 3.9
+    from collections import Iterable
+except ImportError:
+    # Python > 3.9
+    from collections.abc import Iterable
 
 
 class Quantity:
@@ -125,14 +130,14 @@ def get_smv_file(path: str):
     elif os.path.isdir(path):
         files = scan_directory_smv(path)
         if len(files) > 1:
-            raise IOError("There are multiple simulations in the directory:, path")
+            raise IOError("There are multiple simulations in the directory: " + path)
         elif len(files) == 0:
-            raise IOError("No simulations were found in the directory:", path)
+            raise IOError("No simulations were found in the directory: " + path)
         return files[0]
     elif os.path.isfile(path + ".smv"):
         return path + ".smv"
     else:
-        raise IOError("The given path does neither point to a directory nor a file:", path)
+        raise IOError("The given path does neither point to a directory nor a file: " + path)
 
 
 class FDSDataCollection:
